@@ -27,7 +27,7 @@ if [ $? -ne 0 ] ; then exit 1 ; fi
 sec=$(expr $(date '+%s') - $sec)
 if [ $? -ne 0 ] ; then exit 1 ; fi
 
-export LD_PRELOAD="${LD_PRELOAD}${LD_PRELOAD:+:}/usr/lib/datefudge.so"
+export LD_PRELOAD="${LD_PRELOAD}${LD_PRELOAD:+:}/usr/lib/datefudge/datefudge.so"
 export DATEFUDGE=$sec
 
 exec "$@"
